@@ -23,9 +23,9 @@ implementation in Gecko:
 http://developer.mozilla.org/en/docs/Accessibility/ATSPI_Support
 """
 
-__id__        = "$Id: speech_generator.py 4474 2009-01-29 22:02:01Z wwalker $"
-__version__   = "$Revision: 4474 $"
-__date__      = "$Date: 2009-01-29 17:02:01 -0500 (Thu, 29 Jan 2009) $"
+__id__        = "$Id: speech_generator.py 4534 2009-02-13 00:51:45Z wwalker $"
+__version__   = "$Revision: 4534 $"
+__date__      = "$Date: 2009-02-12 19:51:45 -0500 (Thu, 12 Feb 2009) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -79,17 +79,56 @@ class SpeechGenerator(speechgenerator.SpeechGenerator):
 
         utterances = []
         if role or not obj.getRole() in doNotSpeak:
-            utterances.append(rolenames.getSpeechForRoleName(obj, role))
             if obj.getRole() == pyatspi.ROLE_HEADING:
                 level = self._script.getHeadingLevel(obj)
                 if level:
-                    # Translators: this is in reference to a heading level
-                    # in HTML (e.g., For <h3>, the level is 3).
+                    # Translators: the %d is in reference to a heading
+                    # level in HTML (e.g., For <h3>, the level is 3)
+                    # and the %s is in reference to a previously
+                    # translated rolename for the heading.  If you
+                    # change the order of the %s and %d in the string
+                    # (as needed for Hungarian, for example), Orca will
+                    # detect it and do the right thing.
                     #
-                    utterances.append(_("level %d") % level)
+                    headingString = _("%s level %d")
+                    if headingString.index("%s") < headingString.index("%d"):
+                        utterances.append(
+                            headingString \
+                            % (rolenames.getSpeechForRoleName(obj, role),
+                               level))
+                    else:
+                        utterances.append(
+                            headingString \
+                            % (level,
+                               rolenames.getSpeechForRoleName(obj, role)))
+                else:
+                    utterances.append(rolenames.getSpeechForRoleName(obj, role))
+            else:
+                utterances.append(rolenames.getSpeechForRoleName(obj, role))
 
         return utterances
 
+    def _getSpeechForAlert(self, obj, already_focused):
+        """Gets the speech for an alert.  What we do here is first try
+        to see if the alert contains text via embedded object characters.
+        If it does, we speak that text.  If it doesn't, we defer to the
+        super class.  The prototype alert we're shooting for is the one
+        from http://bugzilla.gnome.org/show_bug.cgi?id=570551
+
+        Arguments:
+        - obj: an Accessible
+        - already_focused: False if object just received focus
+
+        Returns a list of utterances to be spoken for the object.
+        """
+
+        text = self._script.expandEOCs(obj)
+        if text:
+            return [text]
+        else:
+            return speechgenerator.SpeechGenerator.\
+                       _getSpeechForAlert(self, obj, already_focused)
+
     def _getSpeechForDocumentFrame(self, obj, already_focused):
         """Gets the speech for a document frame.
 
