@@ -19,9 +19,9 @@
 
 """Speaks information about the current object of interest."""
 
-__id__        = "$Id: where_am_I.py 4166 2008-09-07 05:04:53Z joanied $"
-__version__   = "$Revision: 4166 $"
-__date__      = "$Date: 2008-09-07 01:04:53 -0400 (Sun, 07 Sep 2008) $"
+__id__        = "$Id: where_am_I.py 4471 2009-01-28 17:52:43Z wwalker $"
+__version__   = "$Revision: 4471 $"
+__date__      = "$Date: 2009-01-28 12:52:43 -0500 (Wed, 28 Jan 2009) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -35,7 +35,7 @@ import urlparse, urllib2
 
 from orca_i18n import _ # for gettext support
 from orca_i18n import ngettext  # for ngettext support
-from orca_i18n import Q_ # to provide qualified translatable strings
+from orca_i18n import C_ # to provide qualified translatable strings
 
 class WhereAmI:
 
@@ -220,16 +220,12 @@ class WhereAmI:
             # Translators: this is in reference to a radio button being
             # selected or not.
             #
-            # ONLY TRANSLATE THE PART AFTER THE PIPE CHARACTER |
-            #
-            text = Q_("radiobutton|selected")
+            text = C_("radiobutton", "selected")
         else:
             # Translators: this is in reference to a radio button being
             # selected or not.
             #
-            # ONLY TRANSLATE THE PART AFTER THE PIPE CHARACTER |
-            #
-            text = Q_("radiobutton|not selected")
+            text = C_("radiobutton", "not selected")
 
         utterances.append(text)
 
@@ -564,9 +560,7 @@ class WhereAmI:
             # Translators: when the user selects (highlights) text in
             # a document, Orca lets them know this.
             #
-            # ONLY TRANSLATE THE PART AFTER THE PIPE CHARACTER |
-            #
-            text = Q_("text|selected")
+            text = C_("text", "selected")
             utterances.append(text)
 
         text = self._getObjAccelerator(obj)
@@ -985,9 +979,7 @@ class WhereAmI:
                     # Translators: when the user selects (highlights) text in
                     # a document, Orca lets them know this.
                     #
-                    # ONLY TRANSLATE THE PART AFTER THE PIPE CHARACTER |
-                    #
-                    utterance = [Q_("text|selected")]
+                    utterance = [C_("text", "selected")]
 
         return utterance
 
